===
API
===

Archetypes DataTable field and widget
=====================================

.. automodule:: collective.table.field_widget
    :members:
    :undoc-members:

BrowserView that displays the Table
===================================

.. automodule:: collective.table.browser.table
    :members:
    :undoc-members:


Local source
============

.. automodule:: collective.table.local
    :members:
    :undoc-members:


The `Table` content-type
========================

.. automodule:: collective.table.table
    :members:
    :undoc-members:
